@@ -77,14 +77,14 @@
 #'  [step_novel()]
 #' @examples
 #' rec <- recipes::recipe(head(pima_diabetes), ~.) %>%
-#'   healthcareai:::step_dummy_hcai(weight_class)
+#'   healthcareai::step_dummy_hcai(weight_class)
 #' d <- recipes::prep(rec, training = pima_diabetes)
 #' d <- recipes::bake(d, new_data = pima_diabetes)
 #'
 #' # Specify ref_levels
 #' ref_levels <- list(weight_class = "normal")
 #' rec <- recipes::recipe(head(pima_diabetes), ~.)
-#' rec <- rec %>% healthcareai:::step_dummy_hcai(weight_class,
+#' rec <- rec %>% healthcareai::step_dummy_hcai(weight_class,
 #'                                               levels = ref_levels)
 #'
 step_dummy_hcai <-
@@ -141,7 +141,7 @@ step_dummy_hcai_new <-
 #' @importFrom dplyr bind_cols
 #' @export
 prep.step_dummy_hcai <- function(x, training, info = NULL, ...) {
-  col_names <- terms_select(x$terms, info = info)
+  col_names <- recipes::recipes_eval_select(quos = x$terms, data = training, info = info)
   fac_check <-
     vapply(training[, col_names], is.factor, logical(1))
   if (any(!fac_check))
